summaryrefslogtreecommitdiffstats
path: root/tdecore/tdeapplication.h
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2025-01-13 23:01:29 +0900
committerMichele Calgaro <[email protected]>2025-02-03 21:32:19 +0900
commit0b81a0c481a3a64d5449171a534bc8c91ae73181 (patch)
tree95cd236e86e934f492b4a4a1bd44bcf434a91ab2 /tdecore/tdeapplication.h
parent180ceca8bb26bbe97f60c99e5d172eb8ccd66e6d (diff)
downloadtdelibs-0b81a0c481a3a64d5449171a534bc8c91ae73181.tar.gz
tdelibs-0b81a0c481a3a64d5449171a534bc8c91ae73181.zip
Rename TDEApplication::kApplication() to TDEApplication::tdeApplication() and kapp to tdeApp.
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'tdecore/tdeapplication.h')
-rw-r--r--tdecore/tdeapplication.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/tdecore/tdeapplication.h b/tdecore/tdeapplication.h
index 1922fa462..0383e757e 100644
--- a/tdecore/tdeapplication.h
+++ b/tdecore/tdeapplication.h
@@ -1,4 +1,4 @@
/* This file is part of the KDE libraries
Copyright (C) 1997 Matthias Kalle Dalheimer ([email protected])
Copyright (c) 1998, 1999 KDE Team
@@ -46,7 +46,7 @@ class KSessionManaged;
class TDEStyle;
class KURL;
-#define kapp TDEApplication::kApplication()
+#define tdeApp TDEApplication::tdeApplication()
class TDEApplicationPrivate;
@@ -54,7 +54,7 @@ class TDEApplicationPrivate;
* Controls and provides information to all KDE applications.
*
* Only one object of this class can be instantiated in a single app.
* This instance is always accessible via the 'kapp' global variable.
* See cut() for an example.
*
* This class provides the following services to all KDE applications.
@@ -296,7 +296,7 @@ public:
* to every function that may require it.
* @return the current application object
*/
- static TDEApplication* kApplication() { return KApp; }
+ static TDEApplication* tdeApplication() { return TDEApp; }
/**
* Returns the application session config object.
@@ -619,7 +619,7 @@ public slots:
* If the widget with focus provides a cut() slot, call that slot. Thus for a
* simple application cut can be implemented as:
* \code
- * KStdAction::cut( kapp, TQ_SLOT( cut() ), actionCollection() );
+ * KStdAction::cut( tdeApp, TQ_SLOT( cut() ), actionCollection() );
* \endcode
*/
void cut();
@@ -628,7 +628,7 @@ public slots:
* If the widget with focus provides a copy() slot, call that slot. Thus for a
* simple application copy can be implemented as:
* \code
- * KStdAction::copy( kapp, TQ_SLOT( copy() ), actionCollection() );
+ * KStdAction::copy( tdeApp, TQ_SLOT( copy() ), actionCollection() );
* \endcode
*/
void copy();
@@ -637,7 +637,7 @@ public slots:
* If the widget with focus provides a paste() slot, call that slot. Thus for a
* simple application copy can be implemented as:
* \code
- * KStdAction::paste( kapp, TQ_SLOT( paste() ), actionCollection() );
+ * KStdAction::paste( tdeApp, TQ_SLOT( paste() ), actionCollection() );
* \endcode
*/
void paste();
@@ -646,7 +646,7 @@ public slots:
* If the widget with focus provides a clear() slot, call that slot. Thus for a
* simple application clear() can be implemented as:
* \code
- * new TDEAction( i18n( "Clear" ), "edit-clear", 0, kapp, TQ_SLOT( clear() ), actionCollection(), "clear" );
+ * new TDEAction( i18n( "Clear" ), "edit-clear", 0, tdeApp, TQ_SLOT( clear() ), actionCollection(), "clear" );
* \endcode
*
* Note that for some widgets, this may not provide the intended bahavior. For
@@ -673,7 +673,7 @@ public slots:
* If the widget with focus provides a selectAll() slot, call that slot. Thus for a
* simple application select all can be implemented as:
* \code
- * KStdAction::selectAll( kapp, TQ_SLOT( selectAll() ), actionCollection() );
+ * KStdAction::selectAll( tdeApp, TQ_SLOT( selectAll() ), actionCollection() );
* \endcode
*/
void selectAll();
@@ -898,7 +898,7 @@ public:
* userCaption using a standard layout.
*
* To make a compliant caption
- * for your window, simply do: @p setCaption(kapp->makeStdCaption(yourCaption));
+ * for your window, simply do: @p setCaption(tdeApp->makeStdCaption(yourCaption));
*
* @param userCaption The caption string you want to display in the
* window caption area. Do not include the application name!
@@ -1278,7 +1278,7 @@ protected:
int kipcEventMask;
/// Current application object.
- static TDEApplication *KApp;
+ static TDEApplication *TDEApp;
int pArgc;
/**
@@ -1301,7 +1301,7 @@ protected:
* focused widget if it provides this slot. You can combine this with TDEAction with:
*
* \code
- * KStdAction::deselect( static_cast<MyApplication *>( kapp ), TQ_SLOT( cut() ), actionCollection() );
+ * KStdAction::deselect( static_cast<MyApplication *>( tdeApp ), TQ_SLOT( cut() ), actionCollection() );
* \endcode
*
* @see cut()
@@ -1,4 +1,4 @@
-/* This file is part of the KDE libraries
+/* This file is part of the TDE libraries
Copyright (C) 1997 Matthias Kalle Dalheimer ([email protected])
Copyright (c) 1998, 1999 KDE Team
@@ -54,7 +54,7 @@ class TDEApplicationPrivate;
*
* Only one object of this class can be instantiated in a single app.
-* This instance is always accessible via the 'kapp' global variable.
+* This instance is always accessible via the 'tdeApp' global variable.
* See cut() for an example.
*